pub enum RetryStrategy {
NoRetry,
Immediate {
max_attempts: u32,
},
FixedDelay {
delay: Duration,
max_attempts: u32,
},
ExponentialBackoff {
base: Duration,
max_attempts: u32,
},
}Expand description
Retry strategy for transient errors
Variants
NoRetry
Do not retry.
Immediate
Retry immediately up to a maximum number of attempts.
FixedDelay
Retry with a fixed delay between attempts.
ExponentialBackoff
Retry with exponential backoff.
Implementations
Sourceimpl RetryStrategy
impl RetryStrategy
Sourcepub fn delay_for_attempt(&self, attempt: u32) -> Option<Duration>
pub fn delay_for_attempt(&self, attempt: u32) -> Option<Duration>
Compute the delay for a given retry attempt, or None if exhausted.
Sourcepub fn max_attempts(&self) -> u32
pub fn max_attempts(&self) -> u32
Return the maximum number of retry attempts.